==> source-app-lab-0.2.0.zip: source-app-lab/ui-packages/ui-components/lib/file-tree/FileRow.tsx <==
import * as ContextMenu from '@radix-ui/react-context-menu';
import clsx from 'clsx';
import { RowRendererProps } from 'react-arborist';

import styles from './file-tree.module.scss';
import { TreeNode } from './fileTree.type';
import { isFileNode } from './utils';

type FileRowProps = RowRendererProps<TreeNode> & {
  selectedNode: TreeNode | undefined;
  onSelect: () => void;
  onRename: () => void;
  onDelete: () => void;
  isReadOnly: boolean;
  isBricksSelected?: boolean;
};

const FileRow: React.FC<FileRowProps> = ({
  selectedNode,
  onSelect,
  onRename,
  onDelete,
  isReadOnly,
  isBricksSelected = false,
  ...rowProps
}: FileRowProps) => {
  const { node } = rowProps;

  return (
    <div {...rowProps.attrs} className={styles['tree-row-container']}>
      <ContextMenu.Root>
        <ContextMenu.Trigger
          disabled={isReadOnly || !isFileNode(node.data)}
          className={styles['tree-row-context-menu-trigger']}
        >
          <div
            role="button"
            tabIndex={0}
            className={clsx(styles['tree-row'], {
              [styles['tree-row-selected']]:
                isFileNode(node.data) &&
                selectedNode &&
                node.data.path === selectedNode.path &&
                !isBricksSelected,
            })}
            ref={rowProps.innerRef}
            onFocus={(e): void => e.stopPropagation()}
            onKeyDown={(e): void => {
              if (e.key === 'Enter') {
                onSelect();
              }
            }}
            onClick={(): void => onSelect()}
          >
            {rowProps.children}
          </div>
        </ContextMenu.Trigger>

        {isFileNode(node.data) && (
          <ContextMenu.Portal>
            <ContextMenu.Content className={styles['tree-row-context-menu']}>
              <ContextMenu.Item
                className={styles['tree-row-context-menu-item']}
                onSelect={onRename}
              >
                Rename
              </ContextMenu.Item>
              <ContextMenu.Item
                className={styles['tree-row-context-menu-item']}
                onSelect={onDelete}
              >
                Delete
              </ContextMenu.Item>
            </ContextMenu.Content>
          </ContextMenu.Portal>
        )}
      </ContextMenu.Root>
    </div>
  );
};

export default FileRow;

==> source-app-lab-0.3.0.zip: source-app-lab/ui-packages/ui-components/lib/file-tree/FileRow.tsx <==
import * as ContextMenu from '@radix-ui/react-context-menu';
import clsx from 'clsx';
import { RowRendererProps } from 'react-arborist';

import styles from './file-tree.module.scss';
import { FileContextMenu } from './FileContextMenu';
import { TreeNode } from './fileTree.type';
import { mustHideContextMenu } from './utils';

type FileRowProps = RowRendererProps<TreeNode> & {
  selectedNode: TreeNode | undefined;
  onSelect: () => void;
  onRename: () => void;
  onDelete: () => void;
  onCreate: (type: TreeNode['type'], path: string) => void;
  isProjectReadOnly: boolean;
  isBricksSelected?: boolean;
};

const FileRow: React.FC<FileRowProps> = ({
  selectedNode,
  onSelect,
  onRename,
  onDelete,
  isProjectReadOnly,
  onCreate,
  isBricksSelected = false,
  ...rowProps
}: FileRowProps) => {
  const { node } = rowProps;

  const openFolderAndCreate = (type: TreeNode['type'], path: string) => () => {
    node.toggle();
    onCreate(type, path);
  };

  return (
    <div {...rowProps.attrs} className={styles['tree-row-container']}>
      <ContextMenu.Root>
        <ContextMenu.Trigger
          onContextMenu={(e): false | void =>
            mustHideContextMenu(isProjectReadOnly, node.data) &&
            e.preventDefault()
          } // disable native context menu
          disabled={mustHideContextMenu(isProjectReadOnly, node.data)}
          className={styles['tree-row-context-menu-trigger']}
        >
          <div
            role="button"
            tabIndex={0}
            className={clsx(styles['tree-row'], {
              [styles['tree-row-selected']]:
                // isFileNode(node.data) &&
                selectedNode &&
                node.data.path === selectedNode.path &&
                !isBricksSelected,
            })}
            ref={rowProps.innerRef}
            onFocus={(e): void => e.stopPropagation()}
            onKeyDown={(e): void => {
              if (e.key === 'Enter') {
                onSelect();
              }
            }}
            onClick={(): void => onSelect()}
          >
            {rowProps.children}
          </div>
        </ContextMenu.Trigger>
        <FileContextMenu
          node={node.data}
          onRename={onRename}
          onDelete={onDelete}
          onCreate={openFolderAndCreate}
        />
      </ContextMenu.Root>
    </div>
  );
};

export default FileRow;
